@@ -19,7 +19,7 @@
 #include <string.h>
 // for timeout process in Proxy_connect()
 #include <time.h>
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32)
 	#include <windows.h>
 	/* Windows doesn't have strtok_r, so remap it to strtok_s */
 	#define strtok_r strtok_s
@@ -136,7 +136,7 @@ int Proxy_connect(networkHandles *net, int ssl, const char *hostname)
 				rc = SOCKET_ERROR;
 				break;
 			}
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32)
 			Sleep(250);
 #else
 			usleep(250000);
@@ -272,7 +272,7 @@ void Proxy_specialChars(char* p0, char* p1, b64_size_t *basic_auth_in_len)
 		{
 			*p0++ = *p1++;
 		}
-		else if (isxdigit(*(p1 + 1)) && isxdigit(*(p1 + 2)))
+		else if (isxdigit((unsigned char)*(p1 + 1)) && isxdigit((unsigned char)*(p1 + 2)))
 		{
 			/* next 2 characters are hexa digits */
 			char hex[3];
@@ -350,4 +350,4 @@ int Proxy_setHTTPProxy(Clients* aClient, char* source, char** dest, char** auth_
 	}
 exit:
 	return rc;
-}
\ No newline at end of file
+}
