@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2023 IBM Corp., Ian Craggs and others
+ * Copyright (c) 2009, 2025 IBM Corp., Ian Craggs and others
  *
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
@@ -44,6 +44,10 @@
 
 #include "Heap.h"
 
+#if defined(UNIXSOCK)
+#include <sys/un.h>
+#endif
+
 #if defined(USE_SELECT)
 int isReady(int socket, fd_set* read_set, fd_set* write_set);
 int Socket_continueWrites(fd_set* pwset, SOCKET* socket, mutex_type mutex);
@@ -60,7 +64,7 @@ int Socket_continueWrite(SOCKET socket);
 char* Socket_getaddrname(struct sockaddr* sa, SOCKET sock);
 int Socket_abortWrite(SOCKET socket);
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32)
 #define iov_len len
 #define iov_base buf
 #define snprintf _snprintf
@@ -84,7 +88,7 @@ extern mutex_type socket_mutex;
 int Socket_setnonblocking(SOCKET sock)
 {
 	int rc;
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32)
 	u_long flag = 1L;
 
 	FUNC_ENTRY;
@@ -112,7 +116,7 @@ int Socket_error(char* aString, SOCKET sock)
 {
 	int err;
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32)
 	err = WSAGetLastError();
 #else
 	err = errno;
@@ -125,13 +129,29 @@ int Socket_error(char* aString, SOCKET sock)
 	return err;
 }
 
+#if !defined(_WIN32)
+void SIGPIPE_ignore()
+{
+#if defined(PAHO_IGNORE_WITH_SIGNAL)
+	if (signal(SIGPIPE, SIG_IGN) == SIG_ERR)
+		Log(LOG_ERROR, -1, "Failed to ignore SIG_PIPE, errno %d", errno);
+#else
+	struct sigaction action;
+	if (sigaction(SIGPIPE, NULL, &action) != 0) /* get current action */
+		Log(LOG_ERROR, -1, "sigaction failed to get SIG_PIPE action8, errno %d", errno);
+	action.sa_handler = SIG_IGN;
+	if (sigaction(SIGPIPE, &action, NULL) != 0)
+		Log(LOG_ERROR, -1, "sigaction failed to ignore SIG_PIPE, errno %d", errno);
+#endif
+}
+#endif
 
 /**
  * Initialize the socket module
  */
 void Socket_outInitialize(void)
 {
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32)
 	WORD    winsockVer = 0x0202;
 	WSADATA wsd;
 
@@ -139,7 +159,7 @@ void Socket_outInitialize(void)
 	WSAStartup(winsockVer, &wsd);
 #else
 	FUNC_ENTRY;
-	signal(SIGPIPE, SIG_IGN);
+	SIGPIPE_ignore();
 #endif
 
 	SocketBuffer_initialize();
@@ -188,7 +208,7 @@ void Socket_outTerminate(void)
 		free(mod_s.saved.fds_read);
 #endif
 	SocketBuffer_terminate();
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32)
 	WSACleanup();
 #endif
 	FUNC_EXIT;
@@ -273,7 +293,18 @@ int Socket_addSocket(SOCKET newSd)
 	Paho_thread_lock_mutex(socket_mutex);
 	mod_s.nfds++;
 	if (mod_s.fds_read)
-		mod_s.fds_read = realloc(mod_s.fds_read, mod_s.nfds * sizeof(mod_s.fds_read[0]));
+	{
+		void* newPtr = realloc(mod_s.fds_read, mod_s.nfds * sizeof(mod_s.fds_read[0]));
+		if (newPtr == NULL)
+		{
+			free(mod_s.fds_read);
+			mod_s.fds_read = NULL;
+		}
+		else
+		{
+			mod_s.fds_read = newPtr;
+		}
+	}
 	else
 		mod_s.fds_read = malloc(mod_s.nfds * sizeof(mod_s.fds_read[0]));
 	if (!mod_s.fds_read)
@@ -282,7 +313,18 @@ int Socket_addSocket(SOCKET newSd)
 		goto exit;
 	}
 	if (mod_s.fds_write)
-		mod_s.fds_write = realloc(mod_s.fds_write, mod_s.nfds * sizeof(mod_s.fds_write[0]));
+	{
+		void* newPtr = realloc(mod_s.fds_write, mod_s.nfds * sizeof(mod_s.fds_write[0]));
+		if (newPtr == NULL)
+		{
+			free(mod_s.fds_write);
+			mod_s.fds_write = NULL;
+		}
+		else
+		{
+			mod_s.fds_write = newPtr;
+		}
+	}
 	else
 		mod_s.fds_write = malloc(mod_s.nfds * sizeof(mod_s.fds_write[0]));
 	if (!mod_s.fds_write)
@@ -293,7 +335,7 @@ int Socket_addSocket(SOCKET newSd)
 
 	mod_s.fds_read[mod_s.nfds - 1].fd = newSd;
 	mod_s.fds_write[mod_s.nfds - 1].fd = newSd;
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32)
 	mod_s.fds_read[mod_s.nfds - 1].events = POLLIN;
 	mod_s.fds_write[mod_s.nfds - 1].events = POLLOUT;
 #else
@@ -525,7 +567,18 @@ SOCKET Socket_getReadySocket(int more_work, int timeout, mutex_type mutex, int*
 				}
 			}
 			else if (mod_s.saved.fds_read)
-				mod_s.saved.fds_read = realloc(mod_s.saved.fds_read, mod_s.nfds * sizeof(struct pollfd));
+			{
+				void* newPtr = realloc(mod_s.saved.fds_read, mod_s.nfds * sizeof(struct pollfd));
+				if (newPtr == NULL)
+				{
+					free(mod_s.saved.fds_read);
+					mod_s.saved.fds_read = NULL;
+				}
+				else
+				{
+					mod_s.saved.fds_read = newPtr;
+				}
+			}
 			else
 				mod_s.saved.fds_read = malloc(mod_s.nfds * sizeof(struct pollfd));
 
@@ -538,7 +591,18 @@ SOCKET Socket_getReadySocket(int more_work, int timeout, mutex_type mutex, int*
 				}
 			}
 			else if (mod_s.saved.fds_write)
-				mod_s.saved.fds_write = realloc(mod_s.saved.fds_write, mod_s.nfds * sizeof(struct pollfd));
+			{
+				void* newPtr = realloc(mod_s.saved.fds_write, mod_s.nfds * sizeof(struct pollfd));
+				if (newPtr == NULL)
+				{
+					free(mod_s.saved.fds_write);
+					mod_s.saved.fds_write = NULL;
+				}
+				else
+				{
+					mod_s.saved.fds_write = newPtr;
+				}
+			}
 			else
 				mod_s.saved.fds_write = malloc(mod_s.nfds * sizeof(struct pollfd));
 		}
@@ -720,7 +784,7 @@ int Socket_writev(SOCKET socket, iobuf* iovecs, int count, unsigned long* bytes)
 
 	FUNC_ENTRY;
 	*bytes = 0L;
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32)
 	rc = WSASend(socket, iovecs, count, (LPDWORD)bytes, 0, NULL, NULL);
 	if (rc == SOCKET_ERROR)
 	{
@@ -891,7 +955,7 @@ int Socket_close_only(SOCKET socket)
 	int rc;
 
 	FUNC_ENTRY;
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32)
 	if (shutdown(socket, SD_BOTH) == SOCKET_ERROR)
 		Socket_error("shutdown", socket);
 	if ((rc = closesocket(socket)) == SOCKET_ERROR)
@@ -992,12 +1056,19 @@ int Socket_close(SOCKET socket)
 				/* shift array to remove the socket in question */
 				memmove(fd, fd + 1, (mod_s.nfds - (fd - mod_s.fds_read)) * sizeof(mod_s.fds_read[0]));
 			}
-			mod_s.fds_read = realloc(mod_s.fds_read, sizeof(mod_s.fds_read[0]) * mod_s.nfds);
-			if (mod_s.fds_read == NULL)
-			{
+	    void* newPtr = realloc(mod_s.fds_read, sizeof(mod_s.fds_read[0]) * mod_s.nfds);
+		  if (newPtr == NULL)
+		  {
+		    free(mod_s.fds_read);
+		  	mod_s.fds_read = NULL;
+
 				rc = PAHO_MEMORY_ERROR;
 				goto exit;
-			}
+		  }
+		  else
+		  {
+		    mod_s.fds_read = newPtr;
+		  }
 		}
 		Log(TRACE_MIN, -1, "Removed socket %d", socket);
 	}
@@ -1021,12 +1092,19 @@ int Socket_close(SOCKET socket)
 				/* shift array to remove the socket in question */
 				memmove(fd, fd + 1, (mod_s.nfds - (fd - mod_s.fds_write)) * sizeof(mod_s.fds_write[0]));
 			}
-			mod_s.fds_write = realloc(mod_s.fds_write, sizeof(mod_s.fds_write[0]) * mod_s.nfds);
-			if (mod_s.fds_write == NULL)
+			void* newPtr = realloc(mod_s.fds_write, sizeof(mod_s.fds_write[0]) * mod_s.nfds);
+			if (newPtr == NULL)
 			{
+				free(mod_s.fds_write);
+				mod_s.fds_write = NULL;
+
 				rc = PAHO_MEMORY_ERROR;
 				goto exit;
 			}
+			else
+			{
+				mod_s.fds_write = newPtr;
+			}
 		}
 		Log(TRACE_MIN, -1, "Removed socket %d", socket);
 	}
@@ -1043,6 +1121,7 @@ exit:
 /**
  *  Create a new socket and TCP connect to an address/port
  *  @param addr the address string
+ *  @param assr_len the length of the address string
  *  @param port the TCP port
  *  @param sock returns the new socket
  *  @param timeout the timeout in milliseconds
@@ -1061,13 +1140,13 @@ int Socket_new(const char* addr, size_t addr_len, int port, SOCKET* sock)
 	struct sockaddr_in6 address6;
 #endif
 	int rc = SOCKET_ERROR;
-#if defined(_WIN32) || defined(_WIN64)
-	short family;
+#if defined(_WIN32)
+	short family = AF_INET;
 #else
 	sa_family_t family = AF_INET;
 #endif
 	struct addrinfo *result = NULL;
-	struct addrinfo hints = {0, AF_UNSPEC, SOCK_STREAM, IPPROTO_TCP, 0, NULL, NULL, NULL};
+	struct addrinfo hints = {AI_ADDRCONFIG, AF_UNSPEC, SOCK_STREAM, IPPROTO_TCP, 0, NULL, NULL, NULL};
 
 	FUNC_ENTRY;
 	*sock = SOCKET_ERROR;
@@ -1131,7 +1210,10 @@ int Socket_new(const char* addr, size_t addr_len, int port, SOCKET* sock)
 		{
 			address6.sin6_port = htons(port);
 			address6.sin6_family = family = AF_INET6;
-			memcpy(&address6.sin6_addr, &((struct sockaddr_in6*)(res->ai_addr))->sin6_addr, sizeof(address6.sin6_addr));
+			struct sockaddr_in6* res6 = (struct sockaddr_in6*)(res->ai_addr);
+			memcpy(&address6.sin6_addr, &res6->sin6_addr, sizeof(address6.sin6_addr));
+			memcpy(&address6.sin6_scope_id, &res6->sin6_scope_id, sizeof(address6.sin6_scope_id));
+			memcpy(&address6.sin6_flowinfo, &res6->sin6_flowinfo, sizeof(address6.sin6_flowinfo));
 		}
 		else
 #endif
@@ -1173,13 +1255,13 @@ int Socket_new(const char* addr, size_t addr_len, int port, SOCKET* sock)
 	return codes from send, for testing only!
 */
 #if defined(SMALL_TCP_BUFFER_TESTING)
-        if (1)
-				{
-					int optsend = 100; //2 * 1440;
-					printf("Setting optsend to %d\n", optsend);
-					if (setsockopt(*sock, SOL_SOCKET, SO_SNDBUF, (void*)&optsend, sizeof(optsend)) != 0)
-						Log(LOG_ERROR, -1, "Could not set SO_SNDBUF for socket %d", *sock);
-				}
+			if (1)
+			{
+				int optsend = 100; //2 * 1440;
+				printf("Setting optsend to %d\n", optsend);
+				if (setsockopt(*sock, SOL_SOCKET, SO_SNDBUF, (void*)&optsend, sizeof(optsend)) != 0)
+					Log(LOG_ERROR, -1, "Could not set SO_SNDBUF for socket %d", *sock);
+			}
 #endif
 			Log(TRACE_MIN, -1, "New socket %d for %s, port %d",	*sock, addr, port);
 			if (Socket_addSocket(*sock) == SOCKET_ERROR)
@@ -1198,7 +1280,7 @@ int Socket_new(const char* addr, size_t addr_len, int port, SOCKET* sock)
 				if (rc == EINPROGRESS || rc == EWOULDBLOCK)
 				{
 					SOCKET* pnewSd = (SOCKET*)malloc(sizeof(SOCKET));
-					ListElement* result = NULL;
+					ListElement* listResult = NULL;
 
 					if (!pnewSd)
 					{
@@ -1207,9 +1289,9 @@ int Socket_new(const char* addr, size_t addr_len, int port, SOCKET* sock)
 					}
 					*pnewSd = *sock;
 					Paho_thread_lock_mutex(socket_mutex);
-					result = ListAppend(mod_s.connect_pending, pnewSd, sizeof(SOCKET));
+					listResult = ListAppend(mod_s.connect_pending, pnewSd, sizeof(SOCKET));
 					Paho_thread_unlock_mutex(socket_mutex);
-					if (!result)
+					if (!listResult)
 					{
 						free(pnewSd);
 						rc = PAHO_MEMORY_ERROR;
@@ -1236,6 +1318,58 @@ exit:
 	return rc;
 }
 
+#if defined(UNIXSOCK)
+/**
+ *  Create a new socket and TCP connect to an address/port
+ *  @param addr the address string, which is a file path
+ *  @param assr_len the length of the address string
+ *  @param sock returns the new socket
+ *  @return completion code 0=good, SOCKET_ERROR=fail
+ */
+int Socket_unix_new(const char* addr, size_t addr_len, SOCKET* sock)
+{
+	struct sockaddr_un address;
+	int rc = SOCKET_ERROR;
+
+	FUNC_ENTRY;
+
+	if (addr_len >= sizeof(address.sun_path)) {
+		rc = PAHO_MEMORY_ERROR;
+	}
+	else {
+		address.sun_family = AF_UNIX;
+		memcpy(&address.sun_path, addr, addr_len);
+		address.sun_path[addr_len] = '\0';
+
+		*sock =	socket(AF_UNIX, SOCK_STREAM, 0);
+		if (*sock == INVALID_SOCKET)
+			rc = Socket_error("socket", *sock);
+		else
+		{
+#if defined(NOSIGPIPE)
+			int opt = 1;
+			if (setsockopt(*sock, SOL_SOCKET, SO_NOSIGPIPE, (void*)&opt, sizeof(opt)) != 0)
+				Log(LOG_ERROR, -1, "Could not set SO_NOSIGPIPE for socket %d", *sock);
+#endif
+			Log(TRACE_MIN, -1, "New UNIX socket %d for %s",	*sock, addr);
+			if (Socket_addSocket(*sock) == SOCKET_ERROR)
+				rc = Socket_error("addSocket", *sock);
+			else
+			{
+				/* this will complete immediately, even though we are non-blocking */
+				rc = connect(*sock, (struct sockaddr*)&address, sizeof(address));
+				if (rc == SOCKET_ERROR)
+					rc = Socket_error("connect", *sock);
+			}
+		}
+	}
+
+exit:
+	FUNC_EXIT_RC(rc);
+	return rc;
+}
+#endif
+
 static Socket_writeContinue* writecontinue = NULL;
 
 void Socket_setWriteContinueCallback(Socket_writeContinue* mywritecontinue)
@@ -1473,7 +1607,7 @@ char* Socket_getaddrname(struct sockaddr* sa, SOCKET sock)
 #define PORTLEN 10
 	static char addr_string[ADDRLEN + PORTLEN];
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32)
 	int buflen = ADDRLEN*2;
 	wchar_t buf[ADDRLEN*2];
 	if (WSAAddressToStringW(sa, sizeof(struct sockaddr_in6), NULL, buf, (LPDWORD)&buflen) == SOCKET_ERROR)
