@@ -21,7 +21,7 @@
 #include <stdint.h>
 #include <sys/types.h>
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32)
 #include <errno.h>
 #include <winsock2.h>
 #include <ws2tcpip.h>
@@ -149,6 +149,7 @@ int Socket_new(const char* addr, size_t addr_len, int port, SOCKET* socket, long
 #else
 int Socket_new(const char* addr, size_t addr_len, int port, SOCKET* socket);
 #endif
+int Socket_unix_new(const char* addr, size_t addr_len, SOCKET* sock);
 
 int Socket_noPendingWrites(SOCKET socket);
 char* Socket_getpeer(SOCKET sock);
