@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2018, 2022 Wind River Systems, Inc., Ian Craggs and others
+ * Copyright (c) 2018, 2024 Wind River Systems, Inc., Ian Craggs and others
  *
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
@@ -25,7 +25,11 @@
 
 #include "Base64.h"
 #include "Log.h"
+#if defined(OPENSSL) && OPENSSL_VERSION_NUMBER >= 0x030000000
+#include "openssl/evp.h"
+#else
 #include "SHA1.h"
+#endif
 #include "LinkedList.h"
 #include "MQTTProtocolOut.h"
 #include "SocketBuffer.h"
@@ -43,7 +47,7 @@
 #  define be64toh(x) OSSwapBigToHostInt64(x)
 #elif defined(__FreeBSD__) || defined(__NetBSD__)
 #  include <sys/endian.h>
-#elif defined(_WIN32) || defined(_WIN64)
+#elif defined(_WIN32)
 #  pragma comment(lib, "rpcrt4.lib")
 #  include <rpc.h>
 #  if !(defined(__MINGW32__))
@@ -88,7 +92,7 @@
 
 #define HTTP_PROTOCOL(x) x ? "https" : "http"
 
-#if !(defined(_WIN32) || defined(_WIN64))
+#if !(defined(_WIN32))
 #if defined(USE_LIBUUID)
 #include <uuid/uuid.h>
 #else /* if defined(USE_LIBUUID) */
@@ -121,6 +125,7 @@ static void uuid_generate( uuid_t out )
 }
 
 /** @brief converts a uuid to a string */
+#if 0
 static void uuid_unparse( uuid_t uu, char *out )
 {
 	int i;
@@ -135,8 +140,9 @@ static void uuid_unparse( uuid_t uu, char *out )
 	}
 	*out = '\0';
 }
+#endif
 #endif /* else if defined(USE_LIBUUID) */
-#endif /* if !(defined(_WIN32) || defined(_WIN64)) */
+#endif /* if !(defined(_WIN32)) */
 
 #include "Heap.h"
 
@@ -388,31 +394,42 @@ int WebSocket_connect( networkHandles *net, int ssl, const char *uri)
 	size_t hostname_len;
 	int port = 80;
 	const char *topic = NULL;
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32)
 	UUID uuid;
-#else /* if defined(_WIN32) || defined(_WIN64) */
+#else /* if defined(_WIN32) */
 	uuid_t uuid;
-#endif /* else if defined(_WIN32) || defined(_WIN64) */
+#endif /* else if defined(_WIN32) */
 
 	FUNC_ENTRY;
 	/* Generate UUID */
 	if (net->websocket_key == NULL)
 		net->websocket_key = malloc(25u);
 	else
-		net->websocket_key = realloc(net->websocket_key, 25u);
+	{
+		void* newPtr = realloc(net->websocket_key, 25u);
+		if (newPtr == NULL)
+		{
+			free(net->websocket_key);
+			net->websocket_key = NULL;
+		}
+		else
+		{
+			net->websocket_key = newPtr;
+		}
+	}
 	if (net->websocket_key == NULL)
 	{
 		rc = PAHO_MEMORY_ERROR;
 		goto exit;
 	}
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32)
 	ZeroMemory( &uuid, sizeof(UUID) );
 	UuidCreate( &uuid );
 	Base64_encode( net->websocket_key, 25u, (const b64_data_t*)&uuid, sizeof(UUID) );
-#else /* if defined(_WIN32) || defined(_WIN64) */
+#else /* if defined(_WIN32) */
 	uuid_generate( uuid );
 	Base64_encode( net->websocket_key, 25u, uuid, sizeof(uuid_t) );
-#endif /* else if defined(_WIN32) || defined(_WIN64) */
+#endif /* else if defined(_WIN32) */
 
 	hostname_len = MQTTProtocol_addressPort(uri, &port, &topic, ssl ? WSS_DEFAULT_PORT : WS_DEFAULT_PORT);
 
@@ -701,8 +718,7 @@ char *WebSocket_getdata(networkHandles *net, size_t bytes, size_t* actual_len)
 		/* no current frame, so let's go receive one for the network */
 		if ( !frame )
 		{
-			const int rc =
-				WebSocket_receiveFrame( net, actual_len );
+			rc = WebSocket_receiveFrame( net, actual_len );
 
 			if ( rc == TCPSOCKET_COMPLETE && in_frames && in_frames->first)
 				frame = in_frames->first->content;
@@ -715,7 +731,7 @@ char *WebSocket_getdata(networkHandles *net, size_t bytes, size_t* actual_len)
 
 
 			while (*actual_len < bytes) {
-				const int rc = WebSocket_receiveFrame(net, actual_len);
+				rc = WebSocket_receiveFrame(net, actual_len);
 
 				if (rc != TCPSOCKET_COMPLETE) {
 					goto exit;
@@ -844,7 +860,19 @@ char *WebSocket_getRawSocketData(networkHandles *net, size_t bytes, size_t* actu
 		// resize buffer
 		else
 		{
-			frame_buffer = realloc(frame_buffer, frame_buffer_data_len + *actual_len);
+			void* newPtr = realloc(frame_buffer, frame_buffer_data_len + *actual_len);
+			if (newPtr == NULL)
+			{
+				free(frame_buffer);
+				frame_buffer = NULL;
+
+				rv = NULL;
+				goto exit;
+			}
+			else
+			{
+				frame_buffer = newPtr;
+			}
 			frame_buffer_len = frame_buffer_data_len + *actual_len;
 
 			memcpy(frame_buffer + frame_buffer_data_len, rv, *actual_len);
@@ -857,7 +885,7 @@ char *WebSocket_getRawSocketData(networkHandles *net, size_t bytes, size_t* actu
 		goto exit;
 
 	bytes = bytes_requested;
-    
+
 	// if possible, return data from the buffer
 	if (bytes > 0)
 	{
@@ -1046,9 +1074,9 @@ int WebSocket_receiveFrame(networkHandles *net, size_t *actual_len)
 
 				/* invalid websocket packet must return error */
 				if ( opcode < WebSocket_OP_CONTINUE ||
-				     opcode > WebSocket_OP_PONG ||
-				     ( opcode > WebSocket_OP_BINARY &&
-				       opcode < WebSocket_OP_CLOSE ) )
+					 opcode > WebSocket_OP_PONG ||
+					 ( opcode > WebSocket_OP_BINARY &&
+					   opcode < WebSocket_OP_CLOSE ) )
 				{
 					rc = SOCKET_ERROR;
 					goto exit;
@@ -1062,7 +1090,7 @@ int WebSocket_receiveFrame(networkHandles *net, size_t *actual_len)
 				if ( payload_len == 126 )
 				{
 					/* If 126, the following 2 bytes interpreted as a
-					      16-bit unsigned integer are the payload length. */
+						  16-bit unsigned integer are the payload length. */
 					b = WebSocket_getRawSocketData(net, 2u, &len, &rcs);
 					if (rcs == SOCKET_ERROR)
 					{
@@ -1085,7 +1113,7 @@ int WebSocket_receiveFrame(networkHandles *net, size_t *actual_len)
 				else if ( payload_len == 127 )
 				{
 					 /* If 127, the following 8 bytes interpreted as a 64-bit unsigned integer (the
-					      most significant bit MUST be 0) are the payload length */
+						  most significant bit MUST be 0) are the payload length */
 					b = WebSocket_getRawSocketData(net, 8u, &len, &rcs);
 					if (rcs == SOCKET_ERROR)
 					{
@@ -1167,11 +1195,19 @@ int WebSocket_receiveFrame(networkHandles *net, size_t *actual_len)
 					res->pos = 0u;
 				} else
 				{
-					if ((res = realloc( res, sizeof(struct ws_frame) + cur_len + len )) == NULL)
+					void* newPtr = realloc( res, sizeof(struct ws_frame) + cur_len + len );
+					if (newPtr == NULL)
 					{
+						free(res);
+						res = NULL;
+
 						rc = PAHO_MEMORY_ERROR;
 						goto exit;
 					}
+					else
+					{
+						res = newPtr;
+					}
 				}
 				if (in_frames && in_frames->first)
 					in_frames->first->content = res; /* realloc moves the data */
@@ -1313,24 +1349,60 @@ int WebSocket_upgrade( networkHandles *net )
 	FUNC_ENTRY;
 	if ( net->websocket_key )
 	{
-		SHA_CTX ctx;
-		char ws_key[62u] = { 0 };
-		unsigned char sha_hash[SHA1_DIGEST_LENGTH];
+		char ws_key[62u] = {0};
 		size_t rcv = 0u;
 		char *read_buf;
+#if defined(OPENSSL) && OPENSSL_VERSION_NUMBER >= 0x030000000
+		EVP_MD_CTX *sha1_ctx = NULL;
+		unsigned char sha_hash[EVP_MAX_MD_SIZE];
+		unsigned int sha_len = 0;
+#else
+		SHA_CTX ctx;
+		unsigned char sha_hash[SHA1_DIGEST_LENGTH];
+#endif
 
 		/* calculate the expected websocket key, expected from server */
-		snprintf( ws_key, sizeof(ws_key), "%s%s", net->websocket_key, ws_guid );
+		snprintf(ws_key, sizeof(ws_key), "%s%s", net->websocket_key, ws_guid);
+#if defined(OPENSSL) && OPENSSL_VERSION_NUMBER >= 0x030000000
+		sha1_ctx = EVP_MD_CTX_new();
+		if (sha1_ctx) {
+			rc = EVP_DigestInit(sha1_ctx, EVP_sha1());
+			if (rc == 0)
+				Log(LOG_ERROR, 1, "EVP_DigestInit failed");
+			else
+				rc = EVP_DigestUpdate(sha1_ctx, ws_key, strlen(ws_key));
+			if (rc == 0)
+				Log(LOG_ERROR, 1, "EVP_DigestUpdate failed");
+			else
+				rc = EVP_DigestFinal(sha1_ctx, sha_hash, &sha_len);
+			if (rc == 0)
+				Log(LOG_ERROR, 1, "EVP_DigestFinal failed");
+			EVP_MD_CTX_free(sha1_ctx);
+			if (rc == 0)
+			{
+				rc = SOCKET_ERROR;
+				goto exit;
+			}
+		} else
+		{
+			Log(LOG_ERROR, 1, "EVP_MD_CTX_new failed");
+			rc = SOCKET_ERROR;
+			goto exit;
+		}
+		Base64_encode( ws_key, sizeof(ws_key), sha_hash, sha_len);
+#else
 		SHA1_Init( &ctx );
 		SHA1_Update( &ctx, ws_key, strlen(ws_key));
 		SHA1_Final( sha_hash, &ctx );
 		Base64_encode( ws_key, sizeof(ws_key), sha_hash, SHA1_DIGEST_LENGTH );
+#endif
 
 		read_buf = WebSocket_getRawSocketData( net, 12u, &rcv, &rc);
 		if (rc == SOCKET_ERROR)
 			goto exit;
 
-		if ((read_buf == NULL) || rcv < 12u) {
+		if ((read_buf == NULL) || rcv < 12u)
+		{
 			Log(TRACE_PROTOCOL, 1, "WebSocket upgrade read not complete %lu", rcv );
 			rc = TCPSOCKET_INTERRUPTED;
 			goto exit;
