@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2022 IBM Corp, Ian Craggs
+ * Copyright (c) 2009, 2024 IBM Corp, Ian Craggs
  *
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
@@ -1416,7 +1416,7 @@ exit:
 int main(int argc, char** argv)
 {
 	int rc = 0;
- 	int (*tests[])() = {NULL, test1, test2, test3, test4, test5, test6, test6a};
+ 	int (*tests[])(struct Options) = {NULL, test1, test2, test3, test4, test5, test6, test6a};
 	int i;
 
 	xml = fopen("TEST-test1.xml", "w");
